pub struct CreditRegistrationOverview {
pub health: CreditRegistrationHealth,
pub counts_by_state: Vec<CreditRegistrationStateTotal>,
pub pending_by_reason: PendingReasonCounts,
pub error_codes: Vec<CreditRegistrationErrorCodeTotal>,
pub needs_admin_attention_count: i64,
pub oldest_non_terminal: Option<CreditRegistrationOldestNonTerminal>,
pub throughput: Vec<CreditRegistrationThroughputBucket>,
pub throughput_days: i64,
pub stuck: Vec<CreditRegistrationStuckTotal>,
pub endpoints: Vec<SuotarEndpointStanding>,
pub circuit_breaker: CreditRegistrationCircuitBreakerState,
}Fields
health: CreditRegistrationHealthcounts_by_state: Vec<CreditRegistrationStateTotal>pending_by_reason: PendingReasonCountsThe pending depth split by what each row is waiting on, which the ledger does not store.
error_codes: Vec<CreditRegistrationErrorCodeTotal>needs_admin_attention_count: i64oldest_non_terminal: Option<CreditRegistrationOldestNonTerminal>throughput: Vec<CreditRegistrationThroughputBucket>throughput_days: i64stuck: Vec<CreditRegistrationStuckTotal>endpoints: Vec<SuotarEndpointStanding>circuit_breaker: CreditRegistrationCircuitBreakerStateTrait Implementations
Sourceimpl Clone for CreditRegistrationOverview
impl Clone for CreditRegistrationOverview
Sourcefn clone(&self) -> CreditRegistrationOverview
fn clone(&self) -> CreditRegistrationOverview
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for CreditRegistrationOverview
impl ComposeSchema for CreditRegistrationOverview
Sourceimpl Debug for CreditRegistrationOverview
impl Debug for CreditRegistrationOverview
Sourceimpl<'de> Deserialize<'de> for CreditRegistrationOverview
impl<'de> Deserialize<'de> for CreditRegistrationOverview
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl ToSchema for CreditRegistrationOverview
impl ToSchema for CreditRegistrationOverview
impl StructuralPartialEq for CreditRegistrationOverview