pub struct CreditRegistrationThroughputBucket {
pub day: DateTime<Utc>,
pub registered_count: i64,
pub other_success_count: i64,
pub failed_count: i64,
}Fields
day: DateTime<Utc>registered_count: i64other_success_count: i64duplicate and not_improved: the credit exists, and we did not put it there.
failed_count: i64Trait Implementations
Sourceimpl Clone for CreditRegistrationThroughputBucket
impl Clone for CreditRegistrationThroughputBucket
Sourcefn clone(&self) -> CreditRegistrationThroughputBucket
fn clone(&self) -> CreditRegistrationThroughputBucket
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for CreditRegistrationThroughputBucket
impl ComposeSchema for CreditRegistrationThroughputBucket
Sourceimpl<'de> Deserialize<'de> for CreditRegistrationThroughputBucket
impl<'de> Deserialize<'de> for CreditRegistrationThroughputBucket
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CreditRegistrationThroughputBucket
impl PartialEq for CreditRegistrationThroughputBucket
Sourcefn eq(&self, other: &CreditRegistrationThroughputBucket) -> bool
fn eq(&self, other: &CreditRegistrationThroughputBucket) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ToSchema for CreditRegistrationThroughputBucket
impl ToSchema for CreditRegistrationThroughputBucket
impl StructuralPartialEq for CreditRegistrationThroughputBucket